==> openquake.engine-3.13.0.tar.gz: openquake.engine-3.13.0/openquake/qa_tests_data/classical/README.md <==
| Test ID | Description |
|---------|-------------|
| case_1  | Checks .npz export, raises error when all source are discarded and checks wrong .ini | 
| case_2  | | 
| case_3  | | 
| case_4  | | 
| case_5  | |
| case_6  | | 
| case_7  | | 
| case_8  | | 
| case_9  | |
| case_10 | | 
| case_11 | | 
| case_12 | | 
| case_13 | | 
| case_14 | | 
| case_15 | | 
| case_16 | Sampling 10 logic tree paths out of 759_375 |
| case_17 | | 
| case_18 | | 
| case_19 | Test AvgGMPE | 
| case_20 | | 
| case_21 | | 
| case_22 | | 
| case_23 | | 
| case_24 | |
| case_25 | |
| case_26 | |
| case_27 | |
| case_28 | |
| case_29 | Non-parametric source with one rupture represente by 2 kite surfaces |
| case_30 | |
| case_31 | |
| case_32 | |
| case_33 | |
| case_34 | |
| case_35 | |
| case_36 | |
| case_37 | |
| case_38 | Example with custom_site_id|
| case_39 | |
| case_40 | |
| case_41 | |
| case_42 | |
| case_43 | Test for ps_grid_spacing |
| case_44 | |
| case_45 | |
| case_46 | |
| case_47 | |
| case_48 | |
| case_49 | Test the use of the convolution method to amplify the motion |
| case_50 | Test the use of the kernel method to amplify the motion |
| case_51 | Test the use of a modifiable GMPE |
| case_52 | |
| case_53 | Tests the modifiable GMPE with imt-independent linear scaling factors on median and standard deviation |
| case_54 | Tests the modifiable GMPE with imt-dependent linear scaling factors on median and standard deviation |
| case_55 | Tests the use of amplification functions |
| case_56 | Another test for oversampling (10 samples out of 6) |
| case_57 | Test for sampling AvgPoeGMPE |
| case_58 | Test for the truncatedGRFromSlipAbsolute epistemic uncertainty |
| case_59 | Test for NRCan15SiteTerm |
| case_60 | |
| case_61 | |
| case_62 | Tests a sample model from SHERIFS |
| case_63 | Test for GMM with soiltype |
| case_64 | |
| case_65 | Test for the multi fault source |
| case_66 | |
| case_67 | |
| case_68 | |
| case_69 | |
| case_70 | |
| case_71 | |
| [case_72](https://github.com/gem/oq-engine/tree/master/openquake/qa_tests_data/classical/case_72) | Test calculation with a subset of the 2014 US model | 
| [case_73](https://github.com/gem/oq-engine/tree/master/openquake/qa_tests_data/classical/case_73) | Tests some epistemic uncertainties in a source-specific LT | 
| [case_74](https://github.com/gem/oq-engine/tree/master/openquake/qa_tests_data/classical/case_74) | Tests EAS-based calculation |

==> openquake.engine-3.14.0.tar.gz: openquake.engine-3.14.0/openquake/qa_tests_data/classical/README.md <==
| Test ID | Description |
|---------|-------------|
| case_1  | Checks .npz export, raises error when all source are discarded and checks wrong .ini | 
| case_2  | | 
| case_3  | | 
| case_4  | | 
| case_5  | |
| case_6  | | 
| case_7  | | 
| case_8  | | 
| case_9  | |
| case_10 | | 
| case_11 | | 
| case_12 | | 
| case_13 | | 
| case_14 | | 
| case_15 | | 
| case_16 | Sampling 10 logic tree paths out of 759_375 |
| case_17 | | 
| case_18 | | 
| case_19 | Test AvgGMPE | 
| case_20 | | 
| case_21 | | 
| case_22 | | 
| case_23 | | 
| case_24 | Test collapsing rjb-independent GMPE |
| case_25 | |
| case_26 | |
| case_27 | |
| case_28 | |
| case_29 | Non-parametric source with one rupture represente by 2 kite surfaces |
| case_30 | |
| case_31 | |
| case_32 | |
| case_33 | |
| case_34 | |
| case_35 | |
| case_36 | |
| case_37 | |
| case_38 | Example with custom_site_id|
| case_39 | |
| case_40 | |
| case_41 | |
| case_42 | |
| case_43 | Test for ps_grid_spacing |
| case_44 | |
| case_45 | |
| case_46 | |
| case_47 | |
| case_48 | |
| case_49 | Test the use of the convolution method to amplify the motion |
| case_50 | Test the use of the kernel method to amplify the motion |
| case_51 | Test the use of a modifiable GMPE |
| case_52 | |
| case_53 | Tests the modifiable GMPE with imt-independent linear scaling factors on median and standard deviation |
| case_54 | Tests the modifiable GMPE with imt-dependent linear scaling factors on median and standard deviation |
| case_55 | Tests the use of amplification functions |
| case_56 | Another test for oversampling (10 samples out of 6) |
| case_57 | Test for sampling AvgPoeGMPE |
| case_58 | Test for the truncatedGRFromSlipAbsolute epistemic uncertainty |
| case_59 | Test for NRCan15SiteTerm |
| case_60 | |
| case_61 | |
| case_62 | Tests a sample model from SHERIFS |
| case_63 | Test for GMM with soiltype |
| case_64 | |
| case_65 | Test for the multi fault source |
| case_66 | |
| case_67 | |
| case_68 | |
| case_69 | Collapse area source, 1 site|
| case_70 | |
| case_71 | |
| case_72 | Test calculation with a subset of the 2014 US model | 
| case_73 | Tests some epistemic uncertainties in a source-specific LT | 
| case_74 | Tests EAS-based calculation |
| case_75 | Tests calculation with multi-fault source |
| case_76 | Tests for Canada SHM6 |
| case_77 | Tests Modifiable GMPE with Tabular GMM |
